@@ -6,6 +6,6 @@ from pvder.exceptionutil import ExceptionUtil
 
 
 LogUtil=ExceptionUtil()
-baseDir=os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+baseDir=os.path.dirname(os.path.abspath(__file__))
 logConfig['logFilePath']=os.path.join(baseDir,logConfig['logFilePath'])
 LogUtil.create_logger(**logConfig)
